[![pypi](https://img.shields.io/pypi/v/lnbase_biolab?color=%2334D058&label=pypi%20package)](https://pypi.org/project/lnbase_biolab)

# lnbase-biolab: Generic bio wetlab (`vvhc`)

Read the [docs](https://lamin.ai/docs/lnbase-biolab).
